==> dart_6.9.2.orig.tar.xz: dart-6.9.2/dart/integration/EulerIntegrator.cpp <==
/*
 * Copyright (c) 2011-2019, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#include "dart/integration/EulerIntegrator.hpp"

namespace dart {
namespace integration {

//==============================================================================
EulerIntegrator::EulerIntegrator()
  : Integrator()
{
}

//==============================================================================
EulerIntegrator::~EulerIntegrator()
{
}

//==============================================================================
void EulerIntegrator::integrate(IntegrableSystem* _system, double _dt)
{
  _system->integrateConfigs(_system->getGenVels(), _dt);
  _system->integrateGenVels(_system->evalGenAccs(), _dt);
}

//==============================================================================
void EulerIntegrator::integratePos(IntegrableSystem* _system, double _dt)
{
  _system->integrateConfigs(_system->getGenVels(), _dt);
}

//==============================================================================
void EulerIntegrator::integrateVel(IntegrableSystem* _system, double _dt)
{
  _system->integrateGenVels(_system->evalGenAccs(), _dt);
}

}  // namespace integration
}  // namespace dart

==> dart_6.12.1+dfsg4.orig.tar.xz: dart-6.12.1/dart/integration/EulerIntegrator.cpp <==
/*
 * Copyright (c) 2011-2021, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#include "dart/integration/EulerIntegrator.hpp"

namespace dart {
namespace integration {

//==============================================================================
EulerIntegrator::EulerIntegrator() : Integrator() {}

//==============================================================================
EulerIntegrator::~EulerIntegrator() {}

//==============================================================================
void EulerIntegrator::integrate(IntegrableSystem* _system, double _dt)
{
  _system->integrateConfigs(_system->getGenVels(), _dt);
  _system->integrateGenVels(_system->evalGenAccs(), _dt);
}

//==============================================================================
void EulerIntegrator::integratePos(IntegrableSystem* _system, double _dt)
{
  _system->integrateConfigs(_system->getGenVels(), _dt);
}

//==============================================================================
void EulerIntegrator::integrateVel(IntegrableSystem* _system, double _dt)
{
  _system->integrateGenVels(_system->evalGenAccs(), _dt);
}

} // namespace integration
} // namespace dart
